@@ -18,10 +18,10 @@ namespace PlasmaQuick
 class AppletQuickItem;
 class LayoutChangedProxy;
 
-/**
+/*!
  * @brief The AppletPopup class shows a popup for an applet either in the panel or on the desktop
  *
- * In addition to the new API this class is resizable and can forward any input events recieved
+ * In addition to the new API this class is resizable and can forward any input events received
  * on the margin to the main item
  *
  * Size hints are transferred from the mainItem's size hints.
@@ -29,12 +29,12 @@ class LayoutChangedProxy;
 class PLASMAQUICK_EXPORT AppletPopup : public PopupPlasmaWindow
 {
     Q_OBJECT
-    /**
+    /*!
      * This property holds a pointer to the AppletInterface used by
      */
     Q_PROPERTY(QQuickItem *appletInterface READ appletInterface WRITE setAppletInterface NOTIFY appletInterfaceChanged)
 
-    /**
+    /*!
      * Whether the dialog should be hidden when the dialog loses focus.
      *
      * The default value is @c false.
@@ -56,13 +56,13 @@ Q_SIGNALS:
 
 protected:
     void hideEvent(QHideEvent *event) override;
-    void focusOutEvent(QFocusEvent *event) override;
 
 private:
     void onMainItemChanged();
     void updateMinSize();
     void updateMaxSize();
     void updateSize();
+    void handleFocusChange();
 
     QPointer<AppletQuickItem> m_appletInterface;
     QPointer<QScreen> m_oldScreen;
