@@ -15,7 +15,7 @@
 #include "debug_p.h"
 #include "dialogbackground_p.h"
 #include "dialogshadows_p.h"
-#include "sharedqmlengine.h"
+#include "quickviewsharedengine.h"
 
 #include <QLayout>
 #include <QMenu>
@@ -1188,6 +1188,7 @@ QPoint Dialog::popupPosition(QQuickItem *item, const QSize &size)
             dialogPos.setX(leftPoint.x());
         }
     }
+    bool flippedY = false;
     // ...at the top edge
     if (dialogPos.y() < avail.top()) {
         if (d->location == Plasma::Types::LeftEdge || d->location == Plasma::Types::RightEdge) {
@@ -1196,12 +1197,13 @@ QPoint Dialog::popupPosition(QQuickItem *item, const QSize &size)
         } else {
             // flip it around
             // Note: floating popup goes here.
+            flippedY = true;
             dialogPos.setY(bottomPoint.y());
         }
     }
     // ...at the bottom edge
     if (dialogPos.y() + size.height() > avail.bottom()) {
-        if (d->location == Plasma::Types::LeftEdge || d->location == Plasma::Types::RightEdge) {
+        if (d->location == Plasma::Types::LeftEdge || d->location == Plasma::Types::RightEdge || flippedY) {
             // move it in bounds
             dialogPos.setY(qMax(avail.top(), (avail.bottom() - size.height() + 1)));
         } else {
@@ -1338,7 +1340,7 @@ void Dialog::focusOutEvent(QFocusEvent *ev)
         const QWindow *focusWindow = QGuiApplication::focusWindow();
         bool childHasFocus = focusWindow && ((focusWindow->isActive() && isAncestorOf(focusWindow)) || (focusWindow->type() & Qt::Popup) == Qt::Popup);
 
-        const bool viewClicked = qobject_cast<const PlasmaQuick::SharedQmlEngine *>(focusWindow) || qobject_cast<const ConfigView *>(focusWindow);
+        const bool viewClicked = qobject_cast<const PlasmaQuick::QuickViewSharedEngine *>(focusWindow) || qobject_cast<const ConfigView *>(focusWindow);
 
         if (viewClicked || (!parentHasFocus && !childHasFocus)) {
             setVisible(false);
